@@ -13,12 +13,12 @@ from starlette.routing import WebSocketRoute, compile_path, get_name, iscoroutin
 from starlette.staticfiles import StaticFiles
 from starlette.types import ASGIApp, Receive, Scope, Send
 
-from kupala.disks.file_server import FileServer
 from kupala.exceptions import MethodNotAllowed
 from kupala.middleware import Middleware
 from kupala.requests import Request
 from kupala.resources import get_resource_action
 from kupala.responses import HTMLResponse, JSONResponse, PlainTextResponse, RedirectResponse
+from kupala.storages.file_server import FileServer
 from kupala.templating import TemplateResponse
 from kupala.utils import camel_to_snake, import_string
 
@@ -623,11 +623,9 @@ class Routes(t.Sequence[routing.BaseRoute]):
         app = StaticFiles(directory=directory, packages=packages, html=html, check_dir=check_dir)
         self.mount(path, app, name=name, middleware=middleware)
 
-    def files(
-        self, path: str, *, disk: str = None, name: str = None, middleware: t.Sequence[Middleware] = None
-    ) -> None:
+    def files(self, path: str, *, storage: str, name: str = None, middleware: t.Sequence[Middleware] = None) -> None:
         """Serve file uploads from disk."""
-        app = FileServer(disk=disk)
+        app = FileServer(storage=storage)
         self._routes.append(Mount(path, app, name=name, middleware=middleware))
 
     def host(
